@@ -1,13 +1,15 @@
 package Sub::Versions;
 # ABSTRACT: Subroutine versioning syntactic sugar
 
+use 5.014;
 use strict;
 use warnings;
+
 use Sub::Util 'subname';
 use Devel::Hook;
 use Carp 'croak';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 my $versions;
 my $subspaces;
@@ -96,10 +98,15 @@ sub import {
 
             # pick the highest version that can be called off the object
             my $selected_version = ( grep { $self->can( $method . '_v' . $_ ) } @valid_versions )[0];
-            croak(qq{No "$method" subroutine with "$version" version}) unless ( defined $selected_version );
 
-            $selected_version = 'v' . $selected_version;
-            return sub { $self->$selected_version->$method(@_) };
+            if ( defined $selected_version ) {
+                $selected_version = 'v' . $selected_version;
+                return sub { $self->$selected_version->$method(@_) };
+            }
+
+            return sub { $self->$method(@_) } if ( $self->can($method) );
+
+            croak(qq{No "$method" subroutine with "$version" version});
         } ) unless ( defined &{"$package\::subver"} );
 
         return;
@@ -131,7 +138,7 @@ Sub::Versions - Subroutine versioning syntactic sugar
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Sub-Versions.svg)](https://travis-ci.org/gryphonshafer/Sub-Versions)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Sub-Versions/badge.png)](https://coveralls.io/r/gryphonshafer/Sub-Versions)
